@@ -9,38 +9,15 @@
  * Jansson, namely those things that affect the public API in
  * jansson.h.
  *
- * The CMake system will generate the jansson_config.h file and
- * copy it to the build and install directories.
+ * The configure script copies this file to jansson_config.h and
+ * replaces @var@ substitutions by values that fit your system. If you
+ * cannot run the configure script, you can do the value substitution
+ * by hand.
  */
 
 #ifndef JANSSON_CONFIG_H
 #define JANSSON_CONFIG_H
 
-/* Define this so that we can disable scattered automake configuration in source files */
-#ifndef JANSSON_USING_CMAKE
-#define JANSSON_USING_CMAKE
-#endif
-
-/* Note: when using cmake, JSON_INTEGER_IS_LONG_LONG is not defined nor used,
- * as we will also check for __int64 etc types.
- * (the definition was used in the automake system) */
-
-/* Bring in the cmake-detected defines */
-#define HAVE_STDINT_H 1
-/* #undef HAVE_INTTYPES_H */
-#define HAVE_SYS_TYPES_H 1
-
-/* Include our standard type header for the integer typedef */
-
-#if defined(HAVE_STDINT_H)
-#  include <stdint.h>
-#elif defined(HAVE_INTTYPES_H)
-#  include <inttypes.h>
-#elif defined(HAVE_SYS_TYPES_H)
-#  include <sys/types.h>
-#endif
-
-
 /* If your compiler supports the inline keyword in C, JSON_INLINE is
    defined to `inline', otherwise empty. In C++, the inline is always
    supported. */
@@ -50,13 +27,13 @@
 #define JSON_INLINE inline
 #endif
 
+/* If your compiler supports the `long long` type and the strtoll()
+   library function, JSON_INTEGER_IS_LONG_LONG is defined to 1,
+   otherwise to 0. */
+#define JSON_INTEGER_IS_LONG_LONG 1
 
-#define json_int_t long long
-#define json_strtoint strtoll
-#define JSON_INTEGER_FORMAT "lld"
-
-
-/* If locale.h and localeconv() are available, define to 1, otherwise to 0. */
+/* If locale.h and localeconv() are available, define to 1,
+   otherwise to 0. */
 #define JSON_HAVE_LOCALECONV 1
 
 /* If __atomic builtins are available they will be used to manage
